@@ -1653,10 +1653,6 @@ uc_check_reset (void)
 {
   gchar *title = NULL;
 
-  /* FIXME
-     if (search_dialog != NULL)
-     uc_search_set_exit (TRUE); */
-
   if (treestore != NULL)
     {
       g_object_unref (G_OBJECT (treestore)), treestore = NULL;
@@ -1681,7 +1677,7 @@ uc_check_reset (void)
   uc_application_set_status_bar (0, "");
 
   title = g_strconcat ("gURLChecker ", UC_VERSION, NULL);
-  gtk_window_set_title (GTK_WINDOW (main_window), title);
+  gtk_window_set_title (GTK_WINDOW (WGET ("main_window")), title);
   g_free (title), title = NULL;
 }
 
@@ -2229,9 +2225,10 @@ uc_check_link_get_properties_proto_file (UCLinkProperties * prop,
 	  /* FIXME */
 	  uc_cache_append_source (prop->uid, str, strlen (str));
 	  g_hash_table_replace (tmp, g_strdup (UC_CONTENT_LENGTH),
-				g_strdup_printf ("%u", strlen (str)));
-	  g_hash_table_replace (tmp,
-				g_strdup (UC_HEADER_STATUS),
+				g_strdup_printf ("%lu",
+						 (unsigned long)
+						 strlen (str)));
+	  g_hash_table_replace (tmp, g_strdup (UC_HEADER_STATUS),
 				g_strdup (UC_STATUS_CODE_PAGE_OK));
 
 	  if (prop->link_type != LINK_TYPE_FILE_IMAGE)
